# Generated from GWB.g4 by ANTLR 4.13.2
from antlr4 import *
if "." in __name__:
    from .GWBParser import GWBParser
else:
    from GWBParser import GWBParser

# This class defines a complete listener for a parse tree produced by GWBParser.
class GWBListener(ParseTreeListener):

    # Enter a parse tree produced by GWBParser#start.
    def enterStart(self, ctx:GWBParser.StartContext):
        pass

    # Exit a parse tree produced by GWBParser#start.
    def exitStart(self, ctx:GWBParser.StartContext):
        pass


    # Enter a parse tree produced by GWBParser#branch.
    def enterBranch(self, ctx:GWBParser.BranchContext):
        pass

    # Exit a parse tree produced by GWBParser#branch.
    def exitBranch(self, ctx:GWBParser.BranchContext):
        pass


    # Enter a parse tree produced by GWBParser#deriv.
    def enterDeriv(self, ctx:GWBParser.DerivContext):
        pass

    # Exit a parse tree produced by GWBParser#deriv.
    def exitDeriv(self, ctx:GWBParser.DerivContext):
        pass


    # Enter a parse tree produced by GWBParser#saci.
    def enterSaci(self, ctx:GWBParser.SaciContext):
        pass

    # Exit a parse tree produced by GWBParser#saci.
    def exitSaci(self, ctx:GWBParser.SaciContext):
        pass


    # Enter a parse tree produced by GWBParser#con.
    def enterCon(self, ctx:GWBParser.ConContext):
        pass

    # Exit a parse tree produced by GWBParser#con.
    def exitCon(self, ctx:GWBParser.ConContext):
        pass


    # Enter a parse tree produced by GWBParser#add.
    def enterAdd(self, ctx:GWBParser.AddContext):
        pass

    # Exit a parse tree produced by GWBParser#add.
    def exitAdd(self, ctx:GWBParser.AddContext):
        pass


    # Enter a parse tree produced by GWBParser#fgi.
    def enterFgi(self, ctx:GWBParser.FgiContext):
        pass

    # Exit a parse tree produced by GWBParser#fgi.
    def exitFgi(self, ctx:GWBParser.FgiContext):
        pass


    # Enter a parse tree produced by GWBParser#carb.
    def enterCarb(self, ctx:GWBParser.CarbContext):
        pass

    # Exit a parse tree produced by GWBParser#carb.
    def exitCarb(self, ctx:GWBParser.CarbContext):
        pass


    # Enter a parse tree produced by GWBParser#modi.
    def enterModi(self, ctx:GWBParser.ModiContext):
        pass

    # Exit a parse tree produced by GWBParser#modi.
    def exitModi(self, ctx:GWBParser.ModiContext):
        pass


    # Enter a parse tree produced by GWBParser#qnum.
    def enterQnum(self, ctx:GWBParser.QnumContext):
        pass

    # Exit a parse tree produced by GWBParser#qnum.
    def exitQnum(self, ctx:GWBParser.QnumContext):
        pass


    # Enter a parse tree produced by GWBParser#typi.
    def enterTypi(self, ctx:GWBParser.TypiContext):
        pass

    # Exit a parse tree produced by GWBParser#typi.
    def exitTypi(self, ctx:GWBParser.TypiContext):
        pass


    # Enter a parse tree produced by GWBParser#bridge.
    def enterBridge(self, ctx:GWBParser.BridgeContext):
        pass

    # Exit a parse tree produced by GWBParser#bridge.
    def exitBridge(self, ctx:GWBParser.BridgeContext):
        pass


    # Enter a parse tree produced by GWBParser#ct.
    def enterCt(self, ctx:GWBParser.CtContext):
        pass

    # Exit a parse tree produced by GWBParser#ct.
    def exitCt(self, ctx:GWBParser.CtContext):
        pass


    # Enter a parse tree produced by GWBParser#bos.
    def enterBos(self, ctx:GWBParser.BosContext):
        pass

    # Exit a parse tree produced by GWBParser#bos.
    def exitBos(self, ctx:GWBParser.BosContext):
        pass



del GWBParser