# Generated from WURCS.g4 by ANTLR 4.13.2
from antlr4 import *
if "." in __name__:
    from .WURCSParser import WURCSParser
else:
    from WURCSParser import WURCSParser

# This class defines a complete listener for a parse tree produced by WURCSParser.
class WURCSListener(ParseTreeListener):

    # Enter a parse tree produced by WURCSParser#start.
    def enterStart(self, ctx:WURCSParser.StartContext):
        pass

    # Exit a parse tree produced by WURCSParser#start.
    def exitStart(self, ctx:WURCSParser.StartContext):
        pass


    # Enter a parse tree produced by WURCSParser#whatever.
    def enterWhatever(self, ctx:WURCSParser.WhateverContext):
        pass

    # Exit a parse tree produced by WURCSParser#whatever.
    def exitWhatever(self, ctx:WURCSParser.WhateverContext):
        pass


    # Enter a parse tree produced by WURCSParser#mono.
    def enterMono(self, ctx:WURCSParser.MonoContext):
        pass

    # Exit a parse tree produced by WURCSParser#mono.
    def exitMono(self, ctx:WURCSParser.MonoContext):
        pass


    # Enter a parse tree produced by WURCSParser#order.
    def enterOrder(self, ctx:WURCSParser.OrderContext):
        pass

    # Exit a parse tree produced by WURCSParser#order.
    def exitOrder(self, ctx:WURCSParser.OrderContext):
        pass


    # Enter a parse tree produced by WURCSParser#tree.
    def enterTree(self, ctx:WURCSParser.TreeContext):
        pass

    # Exit a parse tree produced by WURCSParser#tree.
    def exitTree(self, ctx:WURCSParser.TreeContext):
        pass


    # Enter a parse tree produced by WURCSParser#specs.
    def enterSpecs(self, ctx:WURCSParser.SpecsContext):
        pass

    # Exit a parse tree produced by WURCSParser#specs.
    def exitSpecs(self, ctx:WURCSParser.SpecsContext):
        pass


    # Enter a parse tree produced by WURCSParser#sidechain.
    def enterSidechain(self, ctx:WURCSParser.SidechainContext):
        pass

    # Exit a parse tree produced by WURCSParser#sidechain.
    def exitSidechain(self, ctx:WURCSParser.SidechainContext):
        pass


    # Enter a parse tree produced by WURCSParser#organics.
    def enterOrganics(self, ctx:WURCSParser.OrganicsContext):
        pass

    # Exit a parse tree produced by WURCSParser#organics.
    def exitOrganics(self, ctx:WURCSParser.OrganicsContext):
        pass


    # Enter a parse tree produced by WURCSParser#pos.
    def enterPos(self, ctx:WURCSParser.PosContext):
        pass

    # Exit a parse tree produced by WURCSParser#pos.
    def exitPos(self, ctx:WURCSParser.PosContext):
        pass


    # Enter a parse tree produced by WURCSParser#orient.
    def enterOrient(self, ctx:WURCSParser.OrientContext):
        pass

    # Exit a parse tree produced by WURCSParser#orient.
    def exitOrient(self, ctx:WURCSParser.OrientContext):
        pass


    # Enter a parse tree produced by WURCSParser#single_num.
    def enterSingle_num(self, ctx:WURCSParser.Single_numContext):
        pass

    # Exit a parse tree produced by WURCSParser#single_num.
    def exitSingle_num(self, ctx:WURCSParser.Single_numContext):
        pass


    # Enter a parse tree produced by WURCSParser#num.
    def enterNum(self, ctx:WURCSParser.NumContext):
        pass

    # Exit a parse tree produced by WURCSParser#num.
    def exitNum(self, ctx:WURCSParser.NumContext):
        pass



del WURCSParser