# Generated from IUPAC.g4 by ANTLR 4.13.2
from antlr4 import *
if "." in __name__:
    from .IUPACParser import IUPACParser
else:
    from IUPACParser import IUPACParser

# This class defines a complete listener for a parse tree produced by IUPACParser.
class IUPACListener(ParseTreeListener):

    # Enter a parse tree produced by IUPACParser#start.
    def enterStart(self, ctx:IUPACParser.StartContext):
        pass

    # Exit a parse tree produced by IUPACParser#start.
    def exitStart(self, ctx:IUPACParser.StartContext):
        pass


    # Enter a parse tree produced by IUPACParser#begin.
    def enterBegin(self, ctx:IUPACParser.BeginContext):
        pass

    # Exit a parse tree produced by IUPACParser#begin.
    def exitBegin(self, ctx:IUPACParser.BeginContext):
        pass


    # Enter a parse tree produced by IUPACParser#branch.
    def enterBranch(self, ctx:IUPACParser.BranchContext):
        pass

    # Exit a parse tree produced by IUPACParser#branch.
    def exitBranch(self, ctx:IUPACParser.BranchContext):
        pass


    # Enter a parse tree produced by IUPACParser#deriv.
    def enterDeriv(self, ctx:IUPACParser.DerivContext):
        pass

    # Exit a parse tree produced by IUPACParser#deriv.
    def exitDeriv(self, ctx:IUPACParser.DerivContext):
        pass


    # Enter a parse tree produced by IUPACParser#saci.
    def enterSaci(self, ctx:IUPACParser.SaciContext):
        pass

    # Exit a parse tree produced by IUPACParser#saci.
    def exitSaci(self, ctx:IUPACParser.SaciContext):
        pass


    # Enter a parse tree produced by IUPACParser#con.
    def enterCon(self, ctx:IUPACParser.ConContext):
        pass

    # Exit a parse tree produced by IUPACParser#con.
    def exitCon(self, ctx:IUPACParser.ConContext):
        pass


    # Enter a parse tree produced by IUPACParser#add.
    def enterAdd(self, ctx:IUPACParser.AddContext):
        pass

    # Exit a parse tree produced by IUPACParser#add.
    def exitAdd(self, ctx:IUPACParser.AddContext):
        pass


    # Enter a parse tree produced by IUPACParser#fgi.
    def enterFgi(self, ctx:IUPACParser.FgiContext):
        pass

    # Exit a parse tree produced by IUPACParser#fgi.
    def exitFgi(self, ctx:IUPACParser.FgiContext):
        pass


    # Enter a parse tree produced by IUPACParser#carb.
    def enterCarb(self, ctx:IUPACParser.CarbContext):
        pass

    # Exit a parse tree produced by IUPACParser#carb.
    def exitCarb(self, ctx:IUPACParser.CarbContext):
        pass


    # Enter a parse tree produced by IUPACParser#modi.
    def enterModi(self, ctx:IUPACParser.ModiContext):
        pass

    # Exit a parse tree produced by IUPACParser#modi.
    def exitModi(self, ctx:IUPACParser.ModiContext):
        pass


    # Enter a parse tree produced by IUPACParser#qnum.
    def enterQnum(self, ctx:IUPACParser.QnumContext):
        pass

    # Exit a parse tree produced by IUPACParser#qnum.
    def exitQnum(self, ctx:IUPACParser.QnumContext):
        pass


    # Enter a parse tree produced by IUPACParser#typi.
    def enterTypi(self, ctx:IUPACParser.TypiContext):
        pass

    # Exit a parse tree produced by IUPACParser#typi.
    def exitTypi(self, ctx:IUPACParser.TypiContext):
        pass


    # Enter a parse tree produced by IUPACParser#bridge.
    def enterBridge(self, ctx:IUPACParser.BridgeContext):
        pass

    # Exit a parse tree produced by IUPACParser#bridge.
    def exitBridge(self, ctx:IUPACParser.BridgeContext):
        pass


    # Enter a parse tree produced by IUPACParser#ct.
    def enterCt(self, ctx:IUPACParser.CtContext):
        pass

    # Exit a parse tree produced by IUPACParser#ct.
    def exitCt(self, ctx:IUPACParser.CtContext):
        pass



del IUPACParser